summaryrefslogtreecommitdiff
path: root/content/browser/download/base_file.h
diff options
context:
space:
mode:
authorTorne (Richard Coles) <torne@google.com>2014-02-21 12:16:55 +0000
committerTorne (Richard Coles) <torne@google.com>2014-02-21 12:16:55 +0000
commit5d1f7b1de12d16ceb2c938c56701a3e8bfa558f7 (patch)
tree5d4ae202b870bd86673f596f0d424bc4b3e55ebe /content/browser/download/base_file.h
parente862bac9c33104a29d98631d62668ae7b6676510 (diff)
downloadchromium_org-5d1f7b1de12d16ceb2c938c56701a3e8bfa558f7.tar.gz
Merge from Chromium at DEPS revision 251904
This commit was generated by merge_to_master.py. Change-Id: I1f9543259d7d2a57d81aa41a1b84f85837439d21
Diffstat (limited to 'content/browser/download/base_file.h')
-rw-r--r--content/browser/download/base_file.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/content/browser/download/base_file.h b/content/browser/download/base_file.h
index f1686c81fb..139f3cdc63 100644
--- a/content/browser/download/base_file.h
+++ b/content/browser/download/base_file.h
@@ -14,6 +14,7 @@
#include "base/time/time.h"
#include "content/common/content_export.h"
#include "content/public/browser/download_interrupt_reasons.h"
+#include "crypto/sha2.h"
#include "net/base/file_stream.h"
#include "net/base/net_errors.h"
#include "net/base/net_log.h"
@@ -92,8 +93,8 @@ class CONTENT_EXPORT BaseFile {
virtual std::string GetHashState();
// Returns true if the given hash is considered empty. An empty hash is
// a string of size kSha256HashLen that contains only zeros (initial value
// for the hash).
static bool IsEmptyHash(const std::string& hash);
virtual std::string DebugString() const;
@@ -137,8 +138,7 @@ class CONTENT_EXPORT BaseFile {
const char* operation, int os_error,
DownloadInterruptReason reason);
- static const size_t kSha256HashLen = 32;
- static const unsigned char kEmptySha256Hash[kSha256HashLen];
+ static const unsigned char kEmptySha256Hash[crypto::kSHA256Length];
// Full path to the file including the file name.
base::FilePath full_path_;
@@ -167,7 +167,7 @@ class CONTENT_EXPORT BaseFile {
// is set.
scoped_ptr<crypto::SecureHash> secure_hash_;
- unsigned char sha256_hash_[kSha256HashLen];
+ unsigned char sha256_hash_[crypto::kSHA256Length];
// Indicates that this class no longer owns the associated file, and so
// won't delete it on destruction.
@@ -92,8 +93,8 @@ class CONTENT_EXPORT BaseFile {
virtual std::string GetHashState();
// Returns true if the given hash is considered empty. An empty hash is
- // a string of size kSha256HashLen that contains only zeros (initial value
- // for the hash).
+ // a string of size crypto::kSHA256Length that contains only zeros (initial
+ // value for the hash).
static bool IsEmptyHash(const std::string& hash);
virtual std::string DebugString() const;